vouch
vouch: a gleeunit compatible test runner for Gleam.
Tests are discovered as usual, by files in test/ ending in _test
public zero-arity functions ending in _test
See README.md for more information.
Values
pub fn main() -> Nil
Run the test suite, honouring the options given after -- on the
gleam test command line. The entire migration from gleeunit is
swapping it in:
import vouch
pub fn main() {
vouch.main()
}
Exits 0 when every test passed or was skipped, 1 when any test failed or was blocked on a todo (and when no tests were found), 2 on a usage error.